logzio

package module
v0.0.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 28, 2025 License: Apache-2.0 Imports: 3 Imported by: 0

README

logrus-logzio-hook

Build Status

A Logrus hook for shipping logs to Logz.io.

Usage

package main

import (
    "github.com/logzio/logzio-go"
    "github.com/sirupsen/logrus"
    
    "github.com/form3tech-oss/logrus-logzio-hook/pkg/hook"
)

func main() { 
    // Create the Logz.io client.
    s, err := logzio.New("<TOKEN>")
    if err != nil {
        logrus.Fatal(err)
    }
    // Create the Logz.io hook for Logrus.
    h := hook.NewLogzioHook(s)
    defer h.Stop()
    // Add the Logz.io hook to the standard logger.
    logrus.AddHook(h)
    // Happy logging.
    logrus.Info("I'll show up in Logz.io.")
}

License

Copyright 2019 Form3 Financial Cloud

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type LogzioHook

type LogzioHook struct {
	// contains filtered or unexported fields
}

LogzioHook is a Logz.io hook for Logrus.

func NewLogzioHook

func NewLogzioHook(s *logzio.LogzioSender) *LogzioHook

NewLogzioHook returns a new instance of the Logz.io hook for Logrus which uses the specified sender.

func (*LogzioHook) Fire

func (h *LogzioHook) Fire(e *logrus.Entry) error

Fire writes the specified entry to Logz.io.

func (*LogzioHook) Levels

func (h *LogzioHook) Levels() []logrus.Level

Levels returns the set of log levels for which the Logz.io hook is active.

func (*LogzioHook) Stop

func (h *LogzioHook) Stop()

Stop stops the Logz.io sender.

Jump to