Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type LogzioHook ¶
type LogzioHook struct {
// contains filtered or unexported fields
}
LogzioHook is a Logz.io hook for Logrus.
func NewLogzioHook ¶
func NewLogzioHook(s *logzio.LogzioSender) *LogzioHook
NewLogzioHook returns a new instance of the Logz.io hook for Logrus which uses the specified sender.
func (*LogzioHook) Fire ¶
func (h *LogzioHook) Fire(e *logrus.Entry) error
Fire writes the specified entry to Logz.io.
func (*LogzioHook) Levels ¶
func (h *LogzioHook) Levels() []logrus.Level
Levels returns the set of log levels for which the Logz.io hook is active.
Click to show internal directories.
Click to hide internal directories.